nvector.objects.Pvector — nvector 0.7.5 documentation

# nvector.objects.Pvector

class `Pvector`(pvector, frame, scalar=None)

  Cartesian position vector in relative to a frame.

  `__init__`(self, pvector, frame, scalar=None)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(self, pvector, frame[, scalar]) | Initialize self.
  `delta_to`(self, other) | Returns cartesian delta vector from positions a to b decomposed in N.
  `to_ecef_vector`(self) | Returns position as ECEFvector object.
  `to_geo_point`(self) | Returns position as GeoPoint object.
  `to_nvector`(self) | Returns position as Nvector object.

  Attributes

  `azimuth` | Azimuth in radian
  `azimuth_deg` | Azimuth in degree.
  `elevation` | Elevation in radian.
  `elevation_deg` | Elevation in degree.
  `length` | Length of the pvector.